==> nextcloud-20.0.8p0.tgz: nextcloud/apps/support/l10n/zh_CN.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "链接：",
    "Password:" : "密码：",
    "Generating system report failed." : "生成系统报告失败。",
    "Subscription notifications" : "订阅通知",
    "Could not create folder \"System information\" to store generated report." : "无法新建 \"System information\" 文件夹来存储生成的报告。",
    "Could not create file \"%s\" to store generated report." : "无法创建文件 \"%s\" 用于存储报告。",
    "Could not share file \"%s\"." : "无法共享文件 \"%s\"。",
    "Nextcloud Subscription" : "Nextcloud 订阅",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "您的服务器没有 Nextcloud 订阅或者您的订阅已到期。",
    "Your Nextcloud server subscription does not cover your number of users." : "您的Nextcloud服务器订阅无法涵盖您的用户数。",
    "Your Nextcloud Subscription has expired!" : "您的 Nextcloud 订阅已到期！",
    "Your server has no Nextcloud Subscription" : "您的服务器没有 Nextcloud 订阅。",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "您的 Nextcloud 服务器不受 Nextcloud 企业版订阅的支持",
    "A Nextcloud Enterprise Subscription means the original developers behind your self-hosted cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Nextcloud企业版订阅意味着您自托管云服务器背后的原创开发者将以100%的努力来助力您的成功：安全，可扩展性，性能和您服务的功能可用性！",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "如果您的服务器环境损坏，雇员无法工作，您不需要依靠搜索在线论坛来寻找解决办法。您可以直接联系我们经验丰富的工程师！",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "您和提供早期安全信息，缓解措施，补丁和升级的厂商达成了协议。",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "如果您想不受干扰地长期使用当前版本，您不需要运行软件而不安装安全更新。",
    "You have the best expertise at hand to deal with performance and scalability issues." : "您身边将拥有最好的专家来处理性能和可扩展性问题。",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "您将快速找到正确的文档和专家来回答法规遵从问题或满足GDPR，HIPAA及其他监管要求。",
    "We can also provide Outlook integration, Online Office, scalable integrated audio-video and chat communication an other features only available in a limited form for free or develop further integrations and capabilities to your needs." : "我们也能提供Outlook集成，在线办公，可扩展的集成音视频，聊天交流及其他只以有限免费形式可用的特性或者根据您的需求进行深度集成和功能开发。",
    "A subscription helps you get the most out of Nextcloud!" : "订阅将帮助您发挥Nextcloud的最大潜能！",
    "Learn more now" : "现在就了解更多",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "此邮件已由支持应用发送给您位于 %1$s 的Nextcloud实例的所有管理员，因为您的注册用户已超过 %2$s 个。",
    "Your Nextcloud server Subscription is over limit" : "您的Nextcloud服务器订阅已超出限制",
    "Dear admin," : "亲爱的管理员，",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "您的Nextcloud订阅不能涵盖此服务器上当前活跃的用户数。请联系您的Nextcloud账号管理员更新您的订阅！",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s 是您的账号管理员，可通过邮箱 %2$s 或电话 %3$s 取得联系。",
    "Thank you," : "谢谢，",
    "Your Nextcloud team" : "您的Nextcloud团队",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "此邮件已由支持应用发送给您位于 %s 的Nextcloud实例的所有管理员，因为您的用户数已超过您订阅支持的范围。",
    "Your Nextcloud server Subscription is expired" : "您的Nextcloud服务器订阅已到期",
    "Your Nextcloud server Subscription is expired!" : "您的Nextcloud服务器订阅已到期！",
    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "您的Nextcloud订阅已到期！请联系您的Nextcloud账号管理员更新您的订阅！",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "此邮件已由支持应用发送给您位于 %s 的Nextcloud实例的所有管理员，因为您的订阅已到期。",
    "Support" : "支持",
    "Getting support and help for your Nextcloud" : "为您的Nextcloud获取支持和帮助",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "支持应用使您能直接访问支持和咨询资源，提供您的账号管理员的专属联系方式， 查看您的企业版订阅的概览。",
    "Basic subscription" : "基础订阅",
    "Standard subscription" : "标准订阅",
    "Premium subscription" : "豪华订阅",
    "Géant subscription" : "巨无霸订阅",
    "Silver partner subscription" : "银牌合作伙伴订阅",
    "Gold partner subscription" : "金牌合作伙伴订阅",
    "Subscription" : "订阅",
    "Over subscription limit" : "超过订阅限制",
    "Valid subscription" : "有效的订阅",
    "Expired subscription" : "过期的订阅",
    "Subscription key:" : "订阅密钥：",
    "_Expires in %n year_::_Expires in %n years_" : ["将在 %n 年后过期"],
    "_Expires in %n month_::_Expires in %n months_" : ["将在 %n 月后过期"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["将在 %n 周后过期"],
    "_Expires in %n day_::_Expires in %n days_" : ["将在 %n 天后过期"],
    "For an unlimited amount of users" : "无限制的用户数量",
    "_For %n active users_::_For %n active users_" : [" %n 个活跃用户"],
    "_For %n users_::_For %n users_" : ["%n 个用户"],
    "_currently at %n user_::_currently at %n users_" : ["当前为%n个用户"],
    "Includes support for %s" : "包含对%s的支持",
    "Includes support for %1$s & %2$s" : "包含对%1$s和%2$s的支持",
    "Includes support for %1$s, %2$s & %3$s" : "包含对%1$s、%2$s和%3$s的支持",
    "Update subscription key" : "更新订阅密钥",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s是您的账号管理员。如果您对您的订阅有任何问题，请及时联系我们。",
    "You can find answers to common question in our portal and also file support requests there." : "您能在我们的portal上查询常见问题的解决办法，也可以在portal上创建支持请求。",
    "Access Nextcloud portal" : "获得Nextcloud入口",
    "System information" : "系统信息",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "为支持case收集系统信息。下面的按钮将在文件夹 \"系统信息\" 中生成一个文本文件并将其通过有密码保护的公开链接共享。此链接在2周内有效。",
    "Generate system report" : "生成系统报告",
    "Enterprise subscription recommended" : "推荐企业版订阅",
    "No active enterprise subscription" : "无激活的企业版订阅",
    "Unsupported" : "不支持",
    "This Nextcloud server has no Enterprise Subscription." : "此Nextcloud没有企业版订阅。",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Nextcloud企业版订阅帮助您发挥Nextcloud的最大潜能，保护您数据的安全和使您的服务器在任何时候都能可靠地运行。",
    "Advantages" : "优势",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "通过文档和支持获得Nextcloud开发者的专业技术能力",
    "Access to additional capabilities like Outlook integration, online office and more" : "获得Outlook集成，在线办公及其他能力",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "可扩展性专家支持，发挥文件和通话的扩展能力",
    "Optional branding, consulting, architecture advice" : "可选的品牌推广，咨询，架构建议",
    "Confidential security notification service, mitigations, patches and advice" : "保密安全通知服务，缓解措施，补丁及建议",
    "Compliance certification, advice and documentation" : "法规遵从认证，建议和文档",
    "Get a quote" : "获取报价",
    "More information" : "更多信息",
    "Subscription benefits" : "订阅的好处",
    "Pricing" : "定价",
    "Commmunity support" : "社区支持",
    "Forum" : "论坛",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud 是一个被活跃社区支持的免费软件。您可以注册论坛后提问并与其他人交流。",
    "GitHub" : "Github",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud 使用 Github 作为协同工作平台。您可以在那里直接提交错误报告。",
    "Chat" : "聊天",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "在 Freenode 上通过我们的 IRC 频道 #nextcloud 与我们进行交流。",
    "Nextcloud forum" : "Nextcloud 论坛",
    "Nextcloud at GitHub" : "GitHub 上的 Nextcloud",
    "Open chat" : "开启聊天",
    "Subscription key" : "订阅密钥",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "如果您有可用的Nextcloud订阅，请在这里输入您的订阅密钥。",
    "Learn more about an enterprise subscription." : "了解更多关于企业版订阅信息。",
    "Set subscription key" : "设置订阅密钥",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "目前无法正确获取订阅信息。已设置定时重试。请稍后查看。",
    "The subscription key was invalid." : "此订阅密钥无效。",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "此订阅密钥无法被验证，因为此服务器没有互联网连接。请联系支持团队解决这一问题。",
    "The subscription key had an invalid format." : "此订阅密钥格式无效。",
    "While fetching the subscription information an error happened." : "获取订阅信息时发生了一个错误。",
    "The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "下面的按钮将在文件夹 \"系统信息\" 中生成一个文本文件并将其通过有密码保护的公开链接共享。此链接在2周内有效。",
    "News" : "新闻",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "要获取Nextcloud的最新消息请注册我们的通讯并在社交媒体上关注我们。",
    "Like our Facebook page" : "点赞我们的Facebook页面",
    "Follow us on Twitter" : "在Twitter上关注我们",
    "Check out our blog" : "浏览我们的博客",
    "Subscribe to our newsletter" : "订阅我们的最新消息"
},
"nplurals=1; plural=0;");

==> nextcloud-21.0.3.tgz: nextcloud/apps/support/l10n/zh_CN.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "链接：",
    "Password:" : "密码：",
    "Generating system report failed." : "生成系统报告失败。",
    "Could not create folder \"System information\" to store generated report." : "无法新建 \"System information\" 文件夹来存储生成的报告。",
    "Could not create file \"%s\" to store generated report." : "无法创建文件 \"%s\" 用于存储报告。",
    "Could not share file \"%s\". Nevertheless, you can find it in the folder \"System information\"." : "无法共享文件 “%s”。 不过，您可以在 “系统信息” 文件夹中找到它。",
    "Subscription notifications" : "订阅通知",
    "Nextcloud Subscription" : "Nextcloud 订阅",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "您的服务器没有 Nextcloud 订阅或者您的订阅已到期。",
    "Your Nextcloud server subscription does not cover your number of users." : "您的Nextcloud服务器订阅无法涵盖您的用户数。",
    "Your Nextcloud Subscription has expired!" : "您的 Nextcloud 订阅已到期！",
    "Your server has no Nextcloud Subscription" : "您的服务器没有 Nextcloud 订阅。",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "您的 Nextcloud 服务器不受 Nextcloud 企业版订阅的支持",
    "A Nextcloud Enterprise Subscription means the original developers behind your self-hosted cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Nextcloud企业版订阅意味着您自托管云服务器背后的原创开发者将以100%的努力来助力您的成功：安全，可扩展性，性能和您服务的功能可用性！",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "如果您的服务器环境损坏，雇员无法工作，您不需要依靠搜索在线论坛来寻找解决办法。您可以直接联系我们经验丰富的工程师！",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "您和提供早期安全信息，缓解措施，补丁和升级的厂商达成了协议。",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "如果您想不受干扰地长期使用当前版本，您不需要运行软件而不安装安全更新。",
    "You have the best expertise at hand to deal with performance and scalability issues." : "您身边将拥有最好的专家来处理性能和可扩展性问题。",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "您将快速找到正确的文档和专家来回答法规遵从问题或满足GDPR，HIPAA及其他监管要求。",
    "We can also provide Outlook integration, Online Office, scalable integrated audio-video and chat communication and other features only available in a limited form for free or develop further integrations and capabilities to your needs." : "我们还可以提供Outlook集成、在线办公、可扩展的集成音视频和聊天通信和其他功能，这些功能只能在有限的形式下免费提供，或者根据您的需求开发进一步的集成和功能。",
    "A subscription helps you get the most out of Nextcloud!" : "订阅将帮助您发挥Nextcloud的最大潜能！",
    "Learn more now" : "现在就了解更多",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "此邮件已由支持应用发送给您位于 %1$s 的Nextcloud实例的所有管理员，因为您的注册用户已超过 %2$s 个。",
    "Your Nextcloud server Subscription is over limit" : "您的Nextcloud服务器订阅已超出限制",
    "Dear admin," : "亲爱的管理员，",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "您的 Nextcloud 订阅不能涵盖此服务器上当前活跃的用户数。请联系您的 Nextcloud 账号管理员更新您的订阅！",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s 是您的账号管理员，可通过邮箱 %2$s 或电话 %3$s 取得联系。",
    "Thank you," : "谢谢，",
    "Your Nextcloud team" : "您的Nextcloud团队",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "此邮件已由支持应用发送给您位于 %s 的Nextcloud实例的所有管理员，因为您的用户数已超过您订阅支持的范围。",
    "Your Nextcloud server Subscription is expired" : "您的Nextcloud服务器订阅已到期",
    "Your Nextcloud server Subscription is expired!" : "您的Nextcloud服务器订阅已到期！",
    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "您的 Nextcloud 订阅已到期！请联系您的 Nextcloud 账号管理员更新您的订阅！",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "此邮件已由支持应用发送给您位于 %s 的Nextcloud实例的所有管理员，因为您的订阅已到期。",
    "Support" : "支持",
    "Getting support and help for your Nextcloud" : "为您的Nextcloud获取支持和帮助",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "支持应用使您能直接访问支持和咨询资源，提供您的账号管理员的专属联系方式， 查看您的企业版订阅的概览。",
    "Basic subscription" : "基础订阅",
    "Standard subscription" : "标准订阅",
    "Premium subscription" : "豪华订阅",
    "Géant subscription" : "巨无霸订阅",
    "Silver partner subscription" : "银牌合作伙伴订阅",
    "Gold partner subscription" : "金牌合作伙伴订阅",
    "Subscription" : "订阅",
    "Over subscription limit" : "超过订阅限制",
    "Valid subscription" : "有效的订阅",
    "Expired subscription" : "过期的订阅",
    "Subscription key:" : "订阅密钥：",
    "Expires in: " : "过期时间：",
    "_%n year_::_%n years_" : ["%n 年"],
    "_%n month_::_%n months_" : ["%n 月"],
    "_%n week_::_%n weeks_" : ["%n 周"],
    "_%n day_::_%n days_" : ["%n 天"],
    "For an unlimited amount of users" : "无限制的用户数量",
    "_For %n active users_::_For %n active users_" : [" %n 个活跃用户"],
    "_For %n users_::_For %n users_" : ["%n 个用户"],
    "_currently at %n user_::_currently at %n users_" : ["当前为%n个用户"],
    "Includes support for %s" : "包含对%s的支持",
    "Includes support for %1$s & %2$s" : "包含对%1$s和%2$s的支持",
    "Includes support for %1$s, %2$s & %3$s" : "包含对%1$s、%2$s和%3$s的支持",
    "Extended maintenance life cycle" : "延长维护生命周期",
    "Update subscription key" : "更新订阅密钥",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s是您的账号管理员。如果您对您的订阅有任何问题，请及时联系我们。",
    "You can find answers to common question in our portal and also file support requests there." : "您能在我们的portal上查询常见问题的解决办法，也可以在portal上创建支持请求。",
    "Access Nextcloud portal" : "获得Nextcloud入口",
    "System information" : "系统信息",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "为支持case收集系统信息。下面的按钮将在文件夹 \"系统信息\" 中生成一个文本文件并将其通过有密码保护的公开链接共享。此链接在2周内有效。",
    "Generate system report" : "生成系统报告",
    "Enterprise subscription recommended" : "推荐企业版订阅",
    "No active enterprise subscription" : "无激活的企业版订阅",
    "Unsupported" : "不支持",
    "This Nextcloud server has no Enterprise Subscription." : "此Nextcloud没有企业版订阅。",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Nextcloud企业版订阅帮助您发挥Nextcloud的最大潜能，保护您数据的安全和使您的服务器在任何时候都能可靠地运行。",
    "Advantages" : "优势",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "通过文档和支持获得Nextcloud开发者的专业技术能力",
    "Access to additional capabilities like Outlook integration, online office and more" : "获得Outlook集成，在线办公及其他能力",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "可扩展性专家支持，发挥文件和通话的扩展能力",
    "Optional branding, consulting, architecture advice" : "可选的品牌推广，咨询，架构建议",
    "Confidential security notification service, mitigations, patches and advice" : "保密安全通知服务，缓解措施，补丁及建议",
    "Compliance certification, advice and documentation" : "法规遵从认证，建议和文档",
    "Get a quote" : "获取报价",
    "More information" : "更多信息",
    "Subscription benefits" : "订阅的好处",
    "Pricing" : "定价",
    "Community support" : "社区支持",
    "Forum" : "论坛",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud 是一个被活跃社区支持的免费软件。您可以注册论坛后提问并与其他人交流。",
    "GitHub" : "Github",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud 使用 Github 作为协同工作平台。您可以在那里直接提交错误报告。",
    "Chat" : "聊天",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "在 Freenode 上通过我们的 IRC 频道 #nextcloud 与我们进行交流。",
    "Nextcloud forum" : "Nextcloud 论坛",
    "Nextcloud at GitHub" : "GitHub 上的 Nextcloud",
    "Open chat" : "开启聊天",
    "Subscription key" : "订阅密钥",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "如果您有可用的Nextcloud订阅，请在这里输入您的订阅密钥。",
    "Learn more about an enterprise subscription." : "了解更多关于企业版订阅信息。",
    "Set subscription key" : "设置订阅密钥",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "目前无法正确获取订阅信息。已设置定时重试。请稍后查看。",
    "The subscription key was invalid." : "此订阅密钥无效。",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "此订阅密钥无法被验证，因为此服务器没有互联网连接。请联系支持团队解决这一问题。",
    "The subscription key had an invalid format." : "此订阅密钥格式无效。",
    "While fetching the subscription information an error happened." : "获取订阅信息时发生了一个错误。",
    "The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "下面的按钮将在文件夹 \"系统信息\" 中生成一个文本文件并将其通过有密码保护的公开链接共享。此链接在2周内有效。",
    "News" : "新闻",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "要获取Nextcloud的最新消息请注册我们的通讯并在社交媒体上关注我们。",
    "Like our Facebook page" : "点赞我们的Facebook页面",
    "Follow us on Twitter" : "在Twitter上关注我们",
    "Check out our blog" : "浏览我们的博客",
    "Subscribe to our newsletter" : "订阅我们的最新消息"
},
"nplurals=1; plural=0;");
